@@ -23,12 +23,13 @@
 //  Started: JLBC @ Jul-2010
 // ===========================================================================
 
-#include "rawlog-edit-declarations.h"
-
 #include <mrpt/3rdparty/tclap/CmdLine.h>
+#include <mrpt/system/os.h>
 
 #include <memory>
 
+#include "rawlog-edit-declarations.h"
+
 using TOperationFunctor = void (*)(
 	mrpt::io::CFileGZInputStream& in_rawlog, TCLAP::CmdLine& cmdline,
 	bool verbose);
@@ -85,6 +86,12 @@ TCLAP::ValueArg<std::string> arg_output_file(
 	"o", "output", "Output dataset (*.rawlog)", false, "", "dataset_out.rawlog",
 	cmd);
 
+TCLAP::ValueArg<std::string> arg_plugins(
+	"p", "plugins",
+	"Single or comma-separated list of .so/.dll plugins to load for additional "
+	"user-supplied classes",
+	false, "", "mylib.so", cmd);
+
 TCLAP::ValueArg<std::string> arg_outdir(
 	"", "out-dir", "Output directory (used by some commands only)", false, ".",
 	".", cmd);
@@ -438,9 +445,25 @@ int main(int argc, char** argv)
 		if (!cmd.parse(argc, argv))
 			throw std::runtime_error("");  // should exit.
 
+		// sanity check: one and only one operation is allowed:
+		if (unsigned int nOps = std::count_if(
+				arg_ops.begin(), arg_ops.end(),
+				[](const auto& op) { return op->isSet(); });
+			nOps != 1)
+		{
+			THROW_EXCEPTION_FMT(
+				"One and only one operation must be selected by command line "
+				"arguments, but %u provided. Use --help for further details.",
+				nOps);
+		}
+
 		string input_rawlog = arg_input_file.getValue();
 		const bool verbose = !arg_quiet.getValue();
 
+		// Plugins:
+		if (arg_plugins.isSet())
+			mrpt::system::loadPluginModules(arg_plugins.getValue());
+
 		// Check the selected operation:
 		//  Only one of the ops should be selected:
 		string selected_op;
