@@ -8,11 +8,10 @@
    +------------------------------------------------------------------------+ */
 
 #include <CTraitsTest.h>
+#include <gtest/gtest.h>
 #include <mrpt/containers/CDynamicGrid.h>
 #include <mrpt/core/common.h>
 
-#include <gtest/gtest.h>
-
 template class mrpt::CTraitsTest<mrpt::containers::CDynamicGrid<double>>;
 
 using mrpt::containers::CDynamicGrid;
@@ -31,3 +30,18 @@ TEST(CDynamicGrid, GetSetAndResize)
 	EXPECT_NEAR(*grid.cellByPos(3.0, 4.0), 8.0, 1e-10);
 	EXPECT_NEAR(*grid.cellByPos(-2.0, -7.0), 9.0, 1e-10);
 }
+
+TEST(CDynamicGrid, rangeForLoop)
+{
+	CDynamicGrid<int> grid{-10.0, 10.0, -10.0, 10.0, 0.1};
+
+	grid.fill(0);
+	*grid.cellByPos(3.0, 4.0) = 8;
+
+	std::map<int, int> counter;
+
+	for (const int& d : grid) counter[d]++;
+
+	EXPECT_EQ(counter.at(0), 20 * 20 * 10 * 10 - 1);
+	EXPECT_EQ(counter.at(8), 1);
+}
