@@ -8,6 +8,7 @@
    +------------------------------------------------------------------------+ */
 #pragma once
 
+#include <mrpt/containers/yaml.h>
 #include <mrpt/graphs/CNetworkOfPoses.h>
 #include <mrpt/opengl/CGridPlaneXY.h>
 #include <mrpt/opengl/CPointCloud.h>
@@ -15,7 +16,6 @@
 #include <mrpt/opengl/CSetOfObjects.h>
 #include <mrpt/opengl/CSimpleLine.h>
 #include <mrpt/opengl/stock_objects.h>
-#include <mrpt/system/TParameters.h>
 
 namespace mrpt::graphs::detail
 {
@@ -49,34 +49,32 @@ class CVisualizer
 	 */
 	virtual void getAs3DObject(
 		mrpt::opengl::CSetOfObjects::Ptr& object,
-		mrpt::system::TParametersDouble viz_params) const;
+		const mrpt::containers::yaml& viz_params) const;
 
    protected:
 	/**\name Work-splitting methods
 	 * \brief Smaller functions that do add very specific parts to the visual
 	 * representation
 	 *
-	 * Following functions take an optional TParametersDouble instance
-	 * containing
-	 * visualization parameters
-	 *
+	 * Following functions take an optional mrpt::containers::yaml instance
+	 * containing visualization parameters
 	 */
 	/**\{ */
 	virtual void drawGroundGrid(
 		mrpt::opengl::CSetOfObjects::Ptr& object,
-		const mrpt::system::TParametersDouble* viz_params = nullptr) const;
+		const mrpt::containers::yaml* viz_params = nullptr) const;
 	virtual void drawNodeCorners(
 		mrpt::opengl::CSetOfObjects::Ptr& object,
-		const mrpt::system::TParametersDouble* viz_params = nullptr) const;
+		const mrpt::containers::yaml* viz_params = nullptr) const;
 	virtual void drawNodePoints(
 		mrpt::opengl::CSetOfObjects::Ptr& object,
-		const mrpt::system::TParametersDouble* viz_params = nullptr) const;
+		const mrpt::containers::yaml* viz_params = nullptr) const;
 	virtual void drawEdgeRelPoses(
 		mrpt::opengl::CSetOfObjects::Ptr& object,
-		const mrpt::system::TParametersDouble* viz_params = nullptr) const;
+		const mrpt::containers::yaml* viz_params = nullptr) const;
 	virtual void drawEdges(
 		mrpt::opengl::CSetOfObjects::Ptr& object,
-		const mrpt::system::TParametersDouble* viz_params = nullptr) const;
+		const mrpt::containers::yaml* viz_params = nullptr) const;
 
 	/**\} */
 
