@@ -10,10 +10,10 @@
 #include "opengl-precomp.h"	 // Precompiled header
 //
 #include <mrpt/core/Clock.h>
+#include <mrpt/core/backtrace.h>
 #include <mrpt/core/exceptions.h>
 #include <mrpt/opengl/COpenGLBuffer.h>
 #include <mrpt/opengl/opengl_api.h>
-#include <mrpt/system/backtrace.h>
 
 #include <cstdlib>
 #include <iostream>
@@ -61,13 +61,13 @@ void COpenGLBuffer::RAII_Impl::destroy()
 	{
 		// at least, emit a warning:
 		static double tLast = 0;
-		auto tNow = mrpt::Clock::toDouble(mrpt::Clock::now());
+		auto tNow = mrpt::Clock::nowDouble();
 		if (tNow - tLast > 2.0)
 		{
 			tLast = tNow;
 
-			mrpt::system::TCallStackBackTrace bt;
-			mrpt::system::getCallStackBackTrace(bt);
+			mrpt::TCallStackBackTrace bt;
+			mrpt::callStackBackTrace(bt);
 
 			std::cerr << "[COpenGLBuffer::RAII_Impl] *Warning* Leaking memory "
 						 "since Buffer was acquired from a different thread "
