@@ -53,8 +53,11 @@ using namespace mrpt::system;
 // Macros for easy access to memory with the correct types:
 #ifdef _WIN32
 #define LARGE_INTEGER_NUMS reinterpret_cast<LARGE_INTEGER*>(largeInts)
+#define LARGE_INTEGER_NUMS_CONST \
+	reinterpret_cast<const LARGE_INTEGER*>(largeInts)
 #else
 #define TIMEVAL_NUMS reinterpret_cast<struct timespec*>(largeInts)
+#define TIMEVAL_NUMS_CONST reinterpret_cast<const struct timespec*>(largeInts)
 #endif
 
 CTicTac::CTicTac() noexcept
@@ -63,11 +66,11 @@ CTicTac::CTicTac() noexcept
 
 #ifdef _WIN32
 	static_assert(
-		sizeof(largeInts) >= 2 * sizeof(LARGE_INTEGER),
+		sizeof(largeInts) >= 1 * sizeof(LARGE_INTEGER),
 		"sizeof(LARGE_INTEGER) failed!");
 #else
 	static_assert(
-		sizeof(largeInts) >= 2 * sizeof(struct timespec),
+		sizeof(largeInts) >= 1 * sizeof(struct timespec),
 		"sizeof(struct timespec) failed!");
 #endif
 	Tic();
@@ -84,17 +87,19 @@ void CTicTac::Tic() noexcept
 #endif
 }
 
-double CTicTac::Tac() noexcept
+double CTicTac::Tac() const noexcept
 {
 #ifdef _WIN32
-	LARGE_INTEGER* l = LARGE_INTEGER_NUMS;
-	QueryPerformanceCounter(&l[1]);
-	return (l[1].QuadPart - l[0].QuadPart) *
+	const LARGE_INTEGER* l = LARGE_INTEGER_NUMS_CONST;
+	LARGE_INTEGER l1;
+	QueryPerformanceCounter(&l1);
+	return (l1.QuadPart - l[0].QuadPart) *
 		   AuxWindowsTicTac::GetInstance().dbl_period;
 #else
-	auto* ts = TIMEVAL_NUMS;
-	clock_gettime(CLOCK_MONOTONIC, &ts[1]);
-	return static_cast<double>(ts[1].tv_sec - ts[0].tv_sec) +
-		   1e-9 * static_cast<double>(ts[1].tv_nsec - ts[0].tv_nsec);
+	struct timespec ts1;
+	const auto* ts = TIMEVAL_NUMS_CONST;
+	clock_gettime(CLOCK_MONOTONIC, &ts1);
+	return static_cast<double>(ts1.tv_sec - ts[0].tv_sec) +
+		   1e-9 * static_cast<double>(ts1.tv_nsec - ts[0].tv_nsec);
 #endif
 }
